import React from 'react';
import PropTypes from 'prop-types';
import Icon from '../Icon/Icon';

import getStyles from './BarCodeActionIcon.styles';

/**
 * A bar code icon.
 */
const BarCodeActionIcon = (props) => {
    const {
        contextStyles,
        disabled,
        onPress,
        size,
        testID,
    } = props;

    const styles = getStyles(contextStyles);

    // Generate icon props
    const iconProps = {
        contextStyles: {
            container: styles.container,
            icon: styles.icon,
        },
        name: 'barcode-scan',
        size,
    };
    if (disabled) { iconProps.disabled = disabled; }
    if (!disabled && onPress) { iconProps.onPress = onPress; }
    if (testID) { iconProps.testID = testID; }

    return (
        <Icon { ...iconProps } />
    );
};

BarCodeActionIcon.defaultProps = {
    contextStyles: {},
    size: 25,
};

BarCodeActionIcon.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container surrounding the icon */
        container: PropTypes.object,

        /** Styles for the icon */
        icon: PropTypes.object,
    }),

    /** Prevent press events */
    disabled: PropTypes.bool,

    /**
     * Called when the icon was pressed
     * @param {SyntheticEvent} event - The native press event
     */
    onPress: PropTypes.func,

    /**
     * The size of the icon (fontSize can also be used in the icon styles)
     */
    size: PropTypes.number,

    /** Id used for testing */
    testID: PropTypes.string,
};

export default BarCodeActionIcon;
