import React from 'react';
import PropTypes from 'prop-types';
import Ripple from 'react-native-material-ripple';

// Styles
import getStyles from './ButtonBase.styles';

/**
 * A generic button wrapper control.
 */
const ButtonBase = (props) => {
    const {
        contextStyles,
        disabled,
        children,
        onPress,
        onLongPress,
        testID,
    } = props;

    const styles = getStyles(contextStyles);

    // Generate container props
    const containerProps = {
        style: styles.container,
    };
    if (disabled) {
        containerProps.disabled = disabled;
        containerProps.style = styles.disabledContainer;
    }
    if (!disabled && onLongPress) { containerProps.onLongPress = onLongPress; }
    if (!disabled && onPress) { containerProps.onPress = onPress; }
    if (testID) { containerProps.testID = `${testID}__container`; }

    return (
        <Ripple { ...containerProps }>
            { children }
        </Ripple>
    );
};

ButtonBase.propTypes = {
    /** The button content */
    children: PropTypes.node,

    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styling for the main button container */
        container: PropTypes.object,

        /** Styling for the main button container in a disabled state */
        disabledContainer: PropTypes.object,
    }),

    /** Disable presses */
    disabled: PropTypes.bool,

    /**
     * Called when the button is pressed
     * @param {SyntheticEvent} event - The native press event
     */
    onPress: PropTypes.func,

    /**
     * Called when the button is long pressed
     * @param {SyntheticEvent} event - The native long press event
     */
    onLongPress: PropTypes.func,

    /** Id used for testing */
    testID: PropTypes.string,
};

ButtonBase.defaultProps = {
    contextStyles: {},
};

export default ButtonBase;
