// Core component styles
const coreStyles = {
    container: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        paddingHorizontal: 16,
        paddingVertical: 8,

        // Themed
        borderWidth: 1,
        borderStyle: 'solid',
        borderColor: '#000',
        borderRadius: 6,
    },

    disabledContainer: {
        opacity: 0.5,
    },

    icon: {
        flex: 0,
        paddingLeft: 5,
    },

    pickerCancelText: { // cancelTextStyle - ios
    },

    pickerConfirmText: { // confirmTextStyle - ios
    },

    pickerContainer: { // datePickerContainerStyleIOS
    },

    pickerTitleText: { // titleStyle
    },

    text: {
        color: '#000',
    },
};

/**
 * Combine component context styles with core styles
 * @param {Object} contextStyles
 * @return {Object}
 */
const getStyles = (contextStyles = {}) => {
    return {
        container: {
            ...coreStyles.container,
            ...contextStyles.container,
        },

        disabledContainer: {
            ...coreStyles.container,
            ...contextStyles.container,
            ...coreStyles.disabledContainer,
        },

        icon: {
            ...coreStyles.icon,
            ...contextStyles.icon,
        },

        pickerCancelText: { // cancelTextStyle - ios
            ...coreStyles.pickerCancelText,
            ...contextStyles.pickerCancelText,
        },

        pickerConfirmText: { // confirmTextStyle - ios
            ...coreStyles.pickerConfirmText,
            ...contextStyles.pickerConfirmText,
        },

        pickerContainer: { // datePickerContainerStyleIOS
            ...coreStyles.pickerContainer,
            ...contextStyles.pickerContainer,
        },

        pickerTitleText: { // titleStyle
            ...coreStyles.pickerTitleText,
            ...contextStyles.pickerTitleText,
        },

        text: {
            ...coreStyles.text,
            ...contextStyles.text,
        },
    };
};

export default getStyles;
