import React from 'react';
import PropTypes from 'prop-types';
import { email as SendEmail } from 'react-native-communications';
import Icon from '../Icon/Icon';

import getStyles from './EmailActionIcon.styles';

/**
 * An email icon which launches the default email program
 * with the specified value(s) entered into the email 'to' field.
 */
const EmailActionIcon = (props) => {
    const {
        contextStyles,
        disabled,
        size,
        testID,
        value,
    } = props;

    const styles = getStyles(contextStyles);

    // Generate icon props
    const iconProps = {
        contextStyles: {
            container: styles.container,
            icon: styles.icon,
        },
        name: 'email',
        size,
    };
    if (disabled) { iconProps.disabled = disabled; }
    if (!disabled) {
        iconProps.onPress = () => {
            SendEmail([ value ], null, null, null, null);
        };
    }
    if (testID) { iconProps.testID = testID; }

    return (
        <Icon { ...iconProps } />
    );
};

EmailActionIcon.defaultProps = {
    contextStyles: {},
    size: 25,
};

EmailActionIcon.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container surrounding the icon */
        container: PropTypes.object,

        /** Styles for the icon */
        icon: PropTypes.object,
    }),

    /** Prevent press events */
    disabled: PropTypes.bool,

    /**
     * The size of the icon (fontSize can also be used in the icon styles)
     */
    size: PropTypes.number,

    /** Id used for testing */
    testID: PropTypes.string,

    /** The address(es) to populate the email 'to' field */
    value: PropTypes.string.isRequired,
};

export default EmailActionIcon;
