import React from 'react';
import { View } from 'react-native';
import PropTypes from 'prop-types';
import NativeIcon from 'react-native-vector-icons/MaterialCommunityIcons';

import getStyles from './Icon.styles';

/**
 * An icon component.
 * @see https://materialdesignicons.com/
 */
const Icon = (props) => {
    const {
        contextStyles,
        disabled,
        name,
        onLongPress,
        onPress,
        size,
        testID,
    } = props;

    const styles = getStyles(contextStyles);

    // Generate container props
    const containerProps = {
        style: styles.container,
    };
    if (testID) { containerProps.testID = `${testID}__container`; }

    // Generate icon props
    const iconProps = {
        name,
        size,
        style: styles.icon,
    };
    if (!disabled && onLongPress) { iconProps.onLongPress = onLongPress; }
    if (!disabled && onPress) { iconProps.onPress = onPress; }
    if (disabled) { iconProps.disabled = disabled; }
    if (testID) { iconProps.testID = `${testID}__icon`; }

    return (
        <View { ...containerProps }>
            <NativeIcon { ...iconProps } />
        </View>
    );
};

Icon.defaultProps = {
    contextStyles: {},
    size: 25,
};

Icon.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container surrounding the icon */
        container: PropTypes.object,

        /** Styles for the icon */
        icon: PropTypes.object,
    }),

    /** Prevent press events */
    disabled: PropTypes.bool,

    /** Name of the icon */
    name: PropTypes.string.isRequired,

    /**
     * Called when the image was long pressed
     * @param {SyntheticEvent} event - The native long press event
     */
    onLongPress: PropTypes.func,

    /**
     * Called when the image was pressed
     * @param {SyntheticEvent} event - The native press event
     */
    onPress: PropTypes.func,

    /**
     * The size of the icon (fontSize can also be used in the icon styles)
     */
    size: PropTypes.number,

    /** Id used for testing */
    testID: PropTypes.string,
};

export default Icon;
