import React from 'react';
import PropTypes from 'prop-types';
import { TouchableOpacity, View } from 'react-native';
import TextLabel from '../TextLabel/TextLabel';

// Styles
import getStyles from './RadioButton.styles';

/**
 * An on/off radio button control.
 */
const RadioButton = (props) => {
    const {
        contextStyles,
        disabled,
        onPress,
        selected,
        testID,
        text,
    } = props;

    const styles = getStyles(contextStyles);

    // Generate container props
    const containerProps = {
        style: styles.container,
    };
    if (disabled) {
        containerProps.disabled = disabled;
        containerProps.style = styles.disabledContainer;
    }
    if (!disabled && onPress) { containerProps.onPress = onPress; }
    if (testID) { containerProps.testID = `${testID}__container`; }

    // Generate label props
    const labelProps = {
        contextStyles: {
            text: styles.text,
        },
    };
    if (testID) { labelProps.testID = `${testID}__text`; }

    return (
        <TouchableOpacity { ...containerProps }>
            <View style={ styles.outerButton }>
                { selected && <View style={ styles.innerButton } /> }
            </View>
            <TextLabel { ...labelProps }>
                { text }
            </TextLabel>
        </TouchableOpacity>
    );
};

RadioButton.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container surrounding the label and radio button */
        container: PropTypes.object,

        /** Styling for the main container in a disabled state */
        disabledContainer: PropTypes.object,

        /** Styles for the outer button container */
        outerButton: PropTypes.object,

        /** Styles for the inner button container */
        innerButton: PropTypes.object,

        /** Styles for the label text */
        text: PropTypes.object,
    }),

    /** Disables the control */
    disabled: PropTypes.bool,

    /**
     * Called when the radio button is pressed
     * @param {SyntheticEvent} event - The native press event
     */
    onPress: PropTypes.func,

    /** The radio button value  */
    selected: PropTypes.bool,

    /** Id used for testing */
    testID: PropTypes.string,

    /** Text that will be displayed after the radio button */
    text: PropTypes.string,
};

RadioButton.defaultProps = {
    contextStyles: {},
};

export default RadioButton;
