import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { View, Switch as NativeSwitch } from 'react-native';

// Styles
import getStyles from './Switch.styles';

/**
 * An on/off switch control.
 */
class Switch extends Component {
    static propTypes = {
        /** Styles for this component */
        contextStyles: PropTypes.shape({
            /** Styles for the container surrounding the input */
            container: PropTypes.object,

            /** Styles for a native switch component */
            input: PropTypes.object,
        }),

        /** Disables the control */
        disabled: PropTypes.bool,

        /**
         * Called when the switch was changed
         * @param {Boolean} value - The current switch value: on = true, off = false
         */
        onChange: PropTypes.func,

        /** The switch value */
        selected: PropTypes.bool,

        /** Id used for testing */
        testID: PropTypes.string,
    };

    static defaultProps = {
        contextStyles: {},
    };

    constructor(props) {
        super(props);
        const { selected } = props;
        this.state = {
            selected,
        };
    }

    render() {
        const {
            contextStyles,
            disabled,
            onChange,
            testID,
        } = this.props;
        const {
            selected,
        } = this.state;

        const styles = getStyles(contextStyles);

        // Generate container props
        const containerProps = {
            style: styles.container,
        };
        if (testID) { containerProps.testID = `${testID}__container`; }

        // Generate switch props
        const {
            trackColorFalse,
            trackColorTrue,
            ios_backgroundColor,
            thumbColor,
            ...restInputStyles
        } = styles.input;
        const switchProps = {
            ios_backgroundColor,
            style: restInputStyles,
            thumbColor,
            trackColor: {
                false: trackColorFalse,
                true: trackColorTrue,
            },
            value: selected,
        };
        if (onChange) { switchProps.onValueChange = this.handleChange; }
        if (disabled) { switchProps.disabled = disabled; }
        if (testID) { switchProps.testID = `${testID}__switch`; }

        return (
            <View { ...containerProps }>
                <NativeSwitch { ...switchProps } />
            </View>
        );
    }

    componentDidUpdate(prevProps) {
        const { selected: wasSelected } = prevProps;
        const { selected: isSelected } = this.props;
        if (wasSelected !== isSelected) {
            this.reset({ selected: isSelected });
        }
    }

    handleChange = (selected) => {
        const { onChange } = this.props;
        this.setState({ selected }, () => {
            onChange(selected);
        });
    };

    reset(newState) {
        this.setState(newState);
    }
}

export default Switch;
