import React from 'react';
import PropTypes from 'prop-types';
import { web as LinkWebUrl } from 'react-native-communications';
import Url from 'url-parse';
import Icon from '../Icon/Icon';

import getStyles from './WebActionIcon.styles';

/**
 * A web icon which launches the default web
 * browser program and loads the specified URL.
 */
const WebActionIcon = (props) => {
    const {
        contextStyles,
        disabled,
        size,
        testID,
        value,
    } = props;

    const styles = getStyles(contextStyles);

    // Generate icon props
    const iconProps = {
        contextStyles: {
            container: styles.container,
            icon: styles.icon,
        },
        name: 'web',
        size,
    };
    if (disabled) { iconProps.disabled = disabled; }
    if (!disabled) {
        iconProps.onPress = () => {
            const url = new Url(value, {});

            // Populate slashes if missing
            if (!url.slashes) {
                url.set('slashes', true, null);
            }

            // Populate default protocol if missing
            if (!url.protocol) {
                url.set('protocol', 'http:', null);
            }
            LinkWebUrl(url.toString());
        };
    }
    if (testID) { iconProps.testID = testID; }

    return (
        <Icon { ...iconProps } />
    );
};

WebActionIcon.defaultProps = {
    contextStyles: {},
    size: 25,
};

WebActionIcon.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container surrounding the icon */
        container: PropTypes.object,

        /** Styles for the icon */
        icon: PropTypes.object,
    }),

    /** Prevent press events */
    disabled: PropTypes.bool,

    /**
     * The size of the icon (fontSize can also be used in the icon styles)
     */
    size: PropTypes.number,

    /** Id used for testing */
    testID: PropTypes.string,

    /** The address to load in the web browser */
    value: PropTypes.string.isRequired,
};

export default WebActionIcon;
