import React from 'react';
import PropTypes from 'prop-types';
import { View } from 'react-native';
import Icon from 'react-native-vector-icons/FontAwesome5';

import TextField from '../../TextField/TextField';
import getStyles from './AddressSearch.styles';

/**
 * A control that allows search for locations in a map.
 */
const AddressSearch = (props) => {
    const {
        contextStyles,
        onAddressSearch,
        placeholder,
        iconName,
        iconSize,
    } = props;
    const styles = getStyles(contextStyles);

    return (
        <View style={ styles.container }>
            <Icon
                style={ styles.icon }
                name={ iconName }
                size={ iconSize } />
            <TextField
                style={ styles.input }
                placeholder={ placeholder }
                onSubmitEditing={ (textField, ref, e) => onAddressSearch(e.nativeEvent.text) } />
        </View>
    );
};

AddressSearch.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container */
        container: PropTypes.object,

        /** Styles for the icon */
        icon: PropTypes.object,

        /** Styles for the input */
        input: PropTypes.object,
    }),

    /**
    * Called when address is searched
    * @param {String} text - address text
    */
    onAddressSearch: PropTypes.func,

    /** Place holder text to be displayed in textfield */
    placeholder: PropTypes.string,

    /** Icon name to be displayed */
    iconName: PropTypes.string,

    /** Icon size */
    iconSize: PropTypes.number,
};

AddressSearch.defaultProps = {
    contextStyles: {},
    iconName: 'search-location',
    iconSize: 20,
    placeholder: 'Address Search',
};

export default AddressSearch;
