/* eslint-disable react/jsx-indent */
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { WebView } from 'react-native';

export default class PowerBI extends PureComponent {
    static defaultProps = {
        type: 'report',
        tokenType: 1,
        filterPaneEnabled: false,
        navContentPaneEnabled: false,
        layoutType: 2,
        useConfiguration: false,
    };

    static propTypes = {
	    /** The type of embed */
	    type: PropTypes.string,

	    /** Type of Access token. 0 is for AAD token and 1 is for Embed Token */
	    tokenType: PropTypes.oneOf([
	        0,
	        1,
	    ]),

	    /** Access token for thr report */
	    accessToken: PropTypes.string,

	    /** Embed URL of the report */
	    embedUrl: PropTypes.string,

	    /** Report Id */
	    id: PropTypes.string,

	    /** Property to show/hide filter pane */
	    filterPaneEnabled: PropTypes.bool,

	    /** Property to show/hide page navigation */
	    navContentPaneEnabled: PropTypes.bool,

	    /** Layout of the embed powerbi report */
	    layoutType: PropTypes.oneOf([
	        0,
	        1,
	        2,
	        3,
	    ]),

	    /** Defines the language that powerBI uses for localization */
	    language: PropTypes.string,

	    /** Defines the text formatting that powerBI uses for dates, currency etc */
	    formatLocale: PropTypes.string,

	    /** Defines whether to use config object or individual properties */
	    useConfiguration: PropTypes.bool,

	    /** Whole configuration object */
	    embedConfiguration: PropTypes.shape({
	        /** The type of embed */
	    	type: PropTypes.string.isRequired,

	        /** Type of Access token. 0 is for AAD token and 1 is for Embed Token */
	        tokenType: PropTypes.oneOf([
	            0,
	            1,
	        ]).isRequired,

	        /** Access token for thr report */
	    	accessToken: PropTypes.string.isRequired,

	        /** Embed URL of the report */
	    	embedUrl: PropTypes.string.isRequired,

	        /** Report Id */
	        id: PropTypes.string.isRequired,

	        /** Settings for thr report */
	        settings: PropTypes.shape({
	            /** Property to show/hide filter pane */
	            filterPaneEnabled: PropTypes.bool,

	            /** Property to show/hide page navigation */
	            navContentPaneEnabled: PropTypes.bool,

	            /** Layout of the embed powerbi report */
	            layoutType: PropTypes.oneOf([
	                0,
	                1,
	                2,
	                3,
	            ]),

	            /** Locale settings for the report */
	            localeSettings: PropTypes.shape({
	                /** Defines the language that powerBI uses for localization */
	                language: PropTypes.string,

	                /** Defines the text formatting that powerBI uses for dates, currency etc */
	                formatLocale: PropTypes.string,
	            }),
	        }),
	    }),
    };

    render() {
	    const html = this.getTemplate(this.getConfiguration());
	    return (
            <WebView source={ { html } } />
	    );
    }

    /** Helper method to get the configuration for Power Bi report */
  	getConfiguration = () => {
  	    const {
  	        type,
  	        tokenType,
  	        accessToken,
  	        embedUrl,
  	        id,
  	        filterPaneEnabled,
  	        navContentPaneEnabled,
  	        layoutType,
  	        language,
  	        formatLocale,
  	        useConfiguration,
  	        embedConfiguration,
  	    } = this.props;

  	    /** Use Embed Configuration if it is passed */
  	    if (useConfiguration && embedConfiguration) {
  	        return JSON.stringify(embedConfiguration);
  	    }

  	    /** When no config object is available build configuration object */
  	    const configuration = {
  	        type,
  	        tokenType,
  	        accessToken,
  	        embedUrl,
  	        id,
  	        settings: {
  	            filterPaneEnabled,
  	            navContentPaneEnabled,
  	            layoutType,
  	        },
  	    };

  	    /** Apply locale settings for the report */
  	    if (language) {
  	        configuration.settings.localeSettings = {
  	            language,
  	            formatLocale,
  	        };
  	    }

  	    return JSON.stringify(configuration);
  	}

  	/**
	 * Helper method to get the embeding html for webiew
	 * @param {Object} configuration
	 */
  	getTemplate = (configuration) => (`<!doctype html>
		<html>
		<head>
			<meta charset="utf-8" />
			<script src="https://cdn.jsdelivr.net/npm/powerbi-client@2.7.5/dist/powerbi.min.js"></script>
			<style>
				html,
				body,
				#reportContainer {
					width: 100%;
					height: 100%;
					margin: 0;
					background-color: 'transparent';
					-webkit-overflow-scrolling: touch;
				}
				iframe {
					border: 0px
				}
			</style>
		</head>
		
		<body>
			<div id="reportContainer"></div>
			<script>
			var models = window['powerbi-client'].models;
			var config = ${configuration};
			var reportContainer = document.getElementById('reportContainer');
			var report = powerbi.embed(reportContainer, config);
			</script>
		</body>
		</html>`
  	);
}
