import React from 'react';
import MuiIcon from '@material-ui/core/Icon';
import PropTypes from 'prop-types';

// Styles
import getStyles from './Icon.styles';
import './style.css';

/** Default icon size. */
const ICON_SIZE_DEFAULT = 'default';

/**
 * Icon  component :allows a user to view a non-image icon.
 * @see https://material-ui.com/style/icons/
 */
const Icon = (props) => {
    const {
        contextStyles,
        iconName,
        title,
        iconSize,
        testID,
    } = props;

    const styles = getStyles(contextStyles);

    const iconTitle = title || iconName;

    /**
     * If iconName prop is undefined, the container is also not rendered.
     * Have come out of the implementation of theme overide , which is no loger allowing to alter properties such as color of icon etc after the latest version upgrade.
     * Instead, used inline stlye with the MuiIcon component. The styles corresponding to icon are passed as prop to the MuiIcon component.
     */
    if (iconName) {
        return (
            <div
                style={ styles.container }
                className="xha-icon"
                data-testid={ testID && `${testID}__container` }>
                <MuiIcon
                    fontSize={ iconSize }
                    title={ iconTitle }
                    style={ styles.icon }
                    data-testid={ testID && `${testID}__icon` }>
                    { iconName }
                </MuiIcon>
            </div>
        );
    }

    return null;
};

Icon.propTypes = {

    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container surrounding the icon */
        container: PropTypes.object,

        /** Styles for a icon */
        icon: PropTypes.object,
    }),

    /**
     * Name of a XHA UI icon, or an icon element, to render.
     * This prop is required because it determines the content of the component, but it can
     * be explicitly set to falsy values to render nothing.     *
     * If `null` or `undefined` or `false`, this component will render nothing.
     */
    iconName: PropTypes.string.isRequired,

    /**
     * Description string.
     * Browsers usually render this as a tooltip on hover, whereas screen
     * readers will use it for aural feedback.
     * By default, this is set to the icon's name for accessibility.
     */
    title: PropTypes.string,

    /**
     * Size of the icon to be rendered.
     */
    iconSize: PropTypes.oneOf([
        'inherit',
        'default',
        'small',
        'large',
    ]),

    /** Id used for testing */
    testID: PropTypes.string,
};

Icon.defaultProps = {
    contextStyles: {},
    title: '',
    iconSize: ICON_SIZE_DEFAULT,
};

export default Icon;
