/**
 * Core component style object that contains style object
 * for all the styles for Inner elements like Container ,
 * ActivityIndicator and Image.
 */
const coreStyles = {
    container: {
        display: 'inline-flex',
        position: 'relative',
    },

    loadingIndicator: {
        position: 'absolute',
        top: '50%',
        left: '50%',
        alignSelf: 'center',
        width: '80px',
        height: '80px',
    },

    image: {
        width: 320,
        height: 320,
    },
};

/**
 * Combine all styles, including context styles,
 * into a single style object for
 * @param {Object} contextStyles
 * @param {Boolean} isDisabled
 */
const getStyles = (contextStyles, isDisabled = false) => {
    const { loadingIndicator: { width: loadingIndicatorWidth } } = coreStyles;
    return {
        container: {
            ...coreStyles.container,
            ...contextStyles.container,

            // pointer event should be disabled if False
            pointerEvents: isDisabled ? 'none' : 'auto',
        },

        loadingIndicator: {
            ...coreStyles.loadingIndicator,
            ...contextStyles.loadingIndicator,

            // getting the width of the indicator and generating the negative margin from center to align
            marginLeft: 'calc(' + loadingIndicatorWidth + '/-2)',
            marginTop: 'calc(' + loadingIndicatorWidth + '/-2)',
        },

        image: {
            ...coreStyles.image,
            ...contextStyles.image,
        },
    };
};

export default getStyles;
