import React from 'react';
import Dialog from '@material-ui/core/Dialog';
import PropTypes from 'prop-types';
import { createMuiTheme } from '@material-ui/core';
import { ThemeProvider } from '@material-ui/styles';

// Styles
import getStyles from './Modal.styles';

/**
 * A modal that displays content in the middle of the entire viewport and over all other content.
 * @see https://material-ui.com/components/dialogs/
 * @see https://material-ui.com/api/dialog/
 */
const Modal = (props) => {
    const {
        contextStyles,
        children,
        isTransparentOverlay,
        testID,
        isModalOpen,
        onClose,
    } = props;

    const styles = getStyles(contextStyles, isTransparentOverlay);

    const theme = createMuiTheme({
        typography: {
            useNextVariants: true,
        },
        overrides: {
            MuiDialog: {
                // style for overlay
                container: {
                    ...styles.overlay,
                },

                // style for modal
                paper: {
                    ...styles.modal,
                },
            },
        },
    });

    return (
        <ThemeProvider theme={ theme }>
            <Dialog
                data-testid={ testID }
                open={ isModalOpen }
                onClose={ onClose }
                scroll="paper"
                BackdropProps={ { invisible: true } }
                aria-labelledby="alert-dialog-title"
                aria-describedby="alert-dialog-description">
                { children }
            </Dialog>
        </ThemeProvider>
    );
};

Modal.defaultProps = {
    contextStyles: {},
};

Modal.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the overlay */
        overlay: PropTypes.object,

        /** Styles for the modal container */
        modal: PropTypes.object,
    }),

    /** Modal contents */
    children: PropTypes.node,

    /** Called when modal is closable and user closes the modal. */
    onClose: PropTypes.func,

    /** Defines open or closed state of modal */
    isModalOpen: PropTypes.bool,

    /** Changes the overlay darkened fill to transparent */
    isTransparentOverlay: PropTypes.bool,

    /** Id used for testing */
    testID: PropTypes.string,
};

export default Modal;
