import React from 'react';
import PropTypes from 'prop-types';
import { FormLabel } from '@material-ui/core';
import { getStyles } from './TextLabel.styles';

/**
 * Text Label component to display text or label
 * @see https://material-ui.com/style/typography/
 * @see https://material-ui.com/api/typography/
 * @see https://material-ui.com/api/form-label/
 */
const TextLabel = (props) => {
    const {
        contextStyles,
        numberOfLines,
        children,
        onClick,
        testID,
    } = props;

    const styles = getStyles(contextStyles, numberOfLines);
    const formLabelStyles = {
        ...styles.container,
        ...styles.text,
    };

    return (
        <FormLabel
            data-testid={ testID }
            style={ formLabelStyles }
            onClick={ onClick }>
            { children }
        </FormLabel>
    );
};

TextLabel.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container surrounding the text */
        container: PropTypes.object,

        /** Styles for the text */
        text: PropTypes.object,
    }),

    /** The text to display */
    children: PropTypes.string.isRequired,

    /**
     * Used to truncate the text with an ellipsis after
     * computing the text layout, including line wrapping,
     * such that the total number of lines does not exceed this number
     */
    numberOfLines: PropTypes.number,

    /**
     * Called when the text is pressed
     * @param {SyntheticEvent} event - The browser click event
     */
    onClick: PropTypes.func,

    /** Id used for testing */
    testID: PropTypes.string,
};

TextLabel.defaultProps = {
    contextStyles: {},
};

export default TextLabel;
